Module quota

Module quota 

Per-node multi-dimensional quota tracking.

Structs

QuotaConfig
Per-node quota configuration.
QuotaConfigBuilder
Use builder syntax to set the required parameters and finish by calling the method Self::build().
QuotaDimension
Configuration for a single quota dimension (e.g., “rpm” or “tpm”).
QuotaDimensionBuilder
Use builder syntax to set the required parameters and finish by calling the method Self::build().
QuotaTracker
Tracks rate/quota usage for a set of nodes.