Per-node multi-dimensional quota tracking.
Structs
- Quota
Config - Per-node quota configuration.
- Quota
Config Builder - Use builder syntax to set the required parameters and finish by calling the method
Self::build(). - Quota
Dimension - Configuration for a single quota dimension (e.g., “rpm” or “tpm”).
- Quota
Dimension Builder - Use builder syntax to set the required parameters and finish by calling the method
Self::build(). - Quota
Tracker - Tracks rate/quota usage for a set of nodes.